@@ -96,10 +96,13 @@ def download_artifact(
 
     if slice is not None:
         sub_path = path_list_of_artifact(artifact)[slice]
+
+    if sub_path is not None:
         key = key + "/" + sub_path
         path = os.path.join(path, os.path.dirname(sub_path))
         download_s3(key=key, recursive=True, path=path, keep_dir=True,
                     **kwargs)
+        path = os.path.join(path, os.path.basename(sub_path))
         remove_empty_dir_tag(path)
         return path
 
